# Umbra - Manual - Help File

# Table Of Content

- Introduction
- Installation
- Usage
- Api
- Changes
- About

# Introduction

Umbra is the main package of sIBL_GUI and sIBL_Reporter.

# Installation

The following dependencies are needed:

- Python 2.6.7 or Python 2.7.3: http://www.python.org/
- PyQt: http://www.riverbankcomputing.co.uk/

To install Umbra from the Python Package Index you can issue this command in a shell:

    pip install Umbra

or this alternative command:

    easy_install Umbra

You can also directly install from Github source repository:

    git clone git://github.com/KelSolaar/Umbra.git
    cd Umbra
    python setup.py install

If you want to build the documentation you will also need:

- Tidy http://tidy.sourceforge.net/

# Usage

Once installed, you can launch Umbra using this shell command:

    Umbra

Please refer to Umbra - Api for precise usage examples.

# Api

Umbra Api documentation is available here: Umbra - Api

# Changes

Umbra Changes file is available here: Umbra - Changes

# About

Umbra by Thomas Mansencal - 2008 - 2014
Copyright © 2008 - 2014 - Thomas Mansencal - thomas.mansencal@gmail.com
This software is released under terms of GNU GPL V3 license: http://www.gnu.org/licenses/
http://www.thomasmansencal.com/